@@ -5,12 +5,27 @@ from __future__ import annotations
 
 import os
 
-from subprocess import STDOUT, call, check_output
+from subprocess import STDOUT, CalledProcessError, call, check_output
 
 
 def remove_files(fragment_filenames: list[str]) -> None:
-    if fragment_filenames:
-        call(["git", "rm", "--quiet"] + fragment_filenames)
+    if not fragment_filenames:
+        return
+
+    # Filter out files that are unknown to git
+    try:
+        git_fragments = check_output(
+            ["git", "ls-files"] + fragment_filenames, encoding="utf-8"
+        ).split("\n")
+    except CalledProcessError:
+        # we may not be in a git repository
+        git_fragments = []
+
+    git_fragments = [os.path.abspath(f) for f in git_fragments if os.path.isfile(f)]
+    call(["git", "rm", "--quiet", "--force"] + git_fragments)
+    unknown_fragments = set(fragment_filenames) - set(git_fragments)
+    for unknown_fragment in unknown_fragments:
+        os.remove(unknown_fragment)
 
 
 def stage_newsfile(directory: str, filename: str) -> None:
